@@ -3,9 +3,9 @@ Main interface for codepipeline service type definitions.
 
 Usage::
 
-    from mypy_boto3.codepipeline.type_defs import AcknowledgeJobOutputTypeDef
+    from mypy_boto3.codepipeline.type_defs import AWSSessionCredentialsTypeDef
 
-    data: AcknowledgeJobOutputTypeDef = {...}
+    data: AWSSessionCredentialsTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,81 +22,81 @@ else:
 
 
 __all__ = (
-    "AcknowledgeJobOutputTypeDef",
-    "AcknowledgeThirdPartyJobOutputTypeDef",
+    "AWSSessionCredentialsTypeDef",
     "ActionConfigurationPropertyTypeDef",
-    "ActionExecutionFilterTypeDef",
+    "ActionConfigurationTypeDef",
+    "ActionContextTypeDef",
+    "ActionDeclarationTypeDef",
+    "ActionExecutionDetailTypeDef",
+    "ActionExecutionInputTypeDef",
+    "ActionExecutionOutputTypeDef",
+    "ActionExecutionResultTypeDef",
+    "ActionExecutionTypeDef",
     "ActionRevisionTypeDef",
+    "ActionStateTypeDef",
     "ActionTypeIdTypeDef",
     "ActionTypeSettingsTypeDef",
-    "ApprovalResultTypeDef",
-    "ArtifactDetailsTypeDef",
     "ActionTypeTypeDef",
-    "TagTypeDef",
-    "CreateCustomActionTypeOutputTypeDef",
-    "EncryptionKeyTypeDef",
+    "ArtifactDetailTypeDef",
+    "ArtifactDetailsTypeDef",
+    "ArtifactLocationTypeDef",
+    "ArtifactRevisionTypeDef",
     "ArtifactStoreTypeDef",
-    "InputArtifactTypeDef",
-    "OutputArtifactTypeDef",
-    "ActionDeclarationTypeDef",
+    "ArtifactTypeDef",
     "BlockerDeclarationTypeDef",
-    "StageDeclarationTypeDef",
+    "EncryptionKeyTypeDef",
+    "ErrorDetailsTypeDef",
+    "ExecutionTriggerTypeDef",
+    "InputArtifactTypeDef",
+    "JobDataTypeDef",
+    "JobDetailsTypeDef",
+    "JobTypeDef",
+    "ListWebhookItemTypeDef",
+    "OutputArtifactTypeDef",
+    "PipelineContextTypeDef",
     "PipelineDeclarationTypeDef",
+    "PipelineExecutionSummaryTypeDef",
+    "PipelineExecutionTypeDef",
+    "PipelineMetadataTypeDef",
+    "PipelineSummaryTypeDef",
+    "S3ArtifactLocationTypeDef",
+    "S3LocationTypeDef",
+    "SourceRevisionTypeDef",
+    "StageContextTypeDef",
+    "StageDeclarationTypeDef",
+    "StageExecutionTypeDef",
+    "StageStateTypeDef",
+    "StopExecutionTriggerTypeDef",
+    "TagTypeDef",
+    "ThirdPartyJobDataTypeDef",
+    "ThirdPartyJobDetailsTypeDef",
+    "ThirdPartyJobTypeDef",
+    "TransitionStateTypeDef",
+    "WebhookAuthConfigurationTypeDef",
+    "WebhookDefinitionTypeDef",
+    "WebhookFilterRuleTypeDef",
+    "AcknowledgeJobOutputTypeDef",
+    "AcknowledgeThirdPartyJobOutputTypeDef",
+    "ActionExecutionFilterTypeDef",
+    "ApprovalResultTypeDef",
+    "CreateCustomActionTypeOutputTypeDef",
     "CreatePipelineOutputTypeDef",
     "CurrentRevisionTypeDef",
     "ExecutionDetailsTypeDef",
     "FailureDetailsTypeDef",
-    "AWSSessionCredentialsTypeDef",
-    "ActionConfigurationTypeDef",
-    "S3ArtifactLocationTypeDef",
-    "ArtifactLocationTypeDef",
-    "ArtifactTypeDef",
-    "ActionContextTypeDef",
-    "StageContextTypeDef",
-    "PipelineContextTypeDef",
-    "JobDataTypeDef",
-    "JobDetailsTypeDef",
     "GetJobDetailsOutputTypeDef",
-    "ArtifactRevisionTypeDef",
-    "PipelineExecutionTypeDef",
     "GetPipelineExecutionOutputTypeDef",
-    "PipelineMetadataTypeDef",
     "GetPipelineOutputTypeDef",
-    "ErrorDetailsTypeDef",
-    "ActionExecutionTypeDef",
-    "ActionStateTypeDef",
-    "StageExecutionTypeDef",
-    "TransitionStateTypeDef",
-    "StageStateTypeDef",
     "GetPipelineStateOutputTypeDef",
-    "ThirdPartyJobDataTypeDef",
-    "ThirdPartyJobDetailsTypeDef",
     "GetThirdPartyJobDetailsOutputTypeDef",
-    "S3LocationTypeDef",
-    "ArtifactDetailTypeDef",
-    "ActionExecutionInputTypeDef",
-    "ActionExecutionResultTypeDef",
-    "ActionExecutionOutputTypeDef",
-    "ActionExecutionDetailTypeDef",
     "ListActionExecutionsOutputTypeDef",
     "ListActionTypesOutputTypeDef",
-    "ExecutionTriggerTypeDef",
-    "SourceRevisionTypeDef",
-    "StopExecutionTriggerTypeDef",
-    "PipelineExecutionSummaryTypeDef",
     "ListPipelineExecutionsOutputTypeDef",
-    "PipelineSummaryTypeDef",
     "ListPipelinesOutputTypeDef",
     "ListTagsForResourceOutputTypeDef",
-    "WebhookAuthConfigurationTypeDef",
-    "WebhookFilterRuleTypeDef",
-    "WebhookDefinitionTypeDef",
-    "ListWebhookItemTypeDef",
     "ListWebhooksOutputTypeDef",
     "PaginatorConfigTypeDef",
-    "JobTypeDef",
     "PollForJobsOutputTypeDef",
-    "ThirdPartyJobTypeDef",
     "PollForThirdPartyJobsOutputTypeDef",
     "PutActionRevisionOutputTypeDef",
     "PutApprovalResultOutputTypeDef",
@@ -107,24 +107,9 @@ __all__ = (
     "UpdatePipelineOutputTypeDef",
 )
 
-AcknowledgeJobOutputTypeDef = TypedDict(
-    "AcknowledgeJobOutputTypeDef",
-    {
-        "status": Literal[
-            "Created", "Queued", "Dispatched", "InProgress", "TimedOut", "Succeeded", "Failed"
-        ]
-    },
-    total=False,
-)
-
-AcknowledgeThirdPartyJobOutputTypeDef = TypedDict(
-    "AcknowledgeThirdPartyJobOutputTypeDef",
-    {
-        "status": Literal[
-            "Created", "Queued", "Dispatched", "InProgress", "TimedOut", "Succeeded", "Failed"
-        ]
-    },
-    total=False,
+AWSSessionCredentialsTypeDef = TypedDict(
+    "AWSSessionCredentialsTypeDef",
+    {"accessKeyId": str, "secretAccessKey": str, "sessionToken": str},
 )
 
 _RequiredActionConfigurationPropertyTypeDef = TypedDict(
@@ -144,14 +129,117 @@ class ActionConfigurationPropertyTypeDef(
     pass
 
 
-ActionExecutionFilterTypeDef = TypedDict(
-    "ActionExecutionFilterTypeDef", {"pipelineExecutionId": str}, total=False
+ActionConfigurationTypeDef = TypedDict(
+    "ActionConfigurationTypeDef", {"configuration": Dict[str, str]}, total=False
+)
+
+ActionContextTypeDef = TypedDict(
+    "ActionContextTypeDef", {"name": str, "actionExecutionId": str}, total=False
+)
+
+_RequiredActionDeclarationTypeDef = TypedDict(
+    "_RequiredActionDeclarationTypeDef", {"name": str, "actionTypeId": "ActionTypeIdTypeDef"}
+)
+_OptionalActionDeclarationTypeDef = TypedDict(
+    "_OptionalActionDeclarationTypeDef",
+    {
+        "runOrder": int,
+        "configuration": Dict[str, str],
+        "outputArtifacts": List["OutputArtifactTypeDef"],
+        "inputArtifacts": List["InputArtifactTypeDef"],
+        "roleArn": str,
+        "region": str,
+        "namespace": str,
+    },
+    total=False,
+)
+
+
+class ActionDeclarationTypeDef(
+    _RequiredActionDeclarationTypeDef, _OptionalActionDeclarationTypeDef
+):
+    pass
+
+
+ActionExecutionDetailTypeDef = TypedDict(
+    "ActionExecutionDetailTypeDef",
+    {
+        "pipelineExecutionId": str,
+        "actionExecutionId": str,
+        "pipelineVersion": int,
+        "stageName": str,
+        "actionName": str,
+        "startTime": datetime,
+        "lastUpdateTime": datetime,
+        "status": Literal["InProgress", "Abandoned", "Succeeded", "Failed"],
+        "input": "ActionExecutionInputTypeDef",
+        "output": "ActionExecutionOutputTypeDef",
+    },
+    total=False,
+)
+
+ActionExecutionInputTypeDef = TypedDict(
+    "ActionExecutionInputTypeDef",
+    {
+        "actionTypeId": "ActionTypeIdTypeDef",
+        "configuration": Dict[str, str],
+        "resolvedConfiguration": Dict[str, str],
+        "roleArn": str,
+        "region": str,
+        "inputArtifacts": List["ArtifactDetailTypeDef"],
+        "namespace": str,
+    },
+    total=False,
+)
+
+ActionExecutionOutputTypeDef = TypedDict(
+    "ActionExecutionOutputTypeDef",
+    {
+        "outputArtifacts": List["ArtifactDetailTypeDef"],
+        "executionResult": "ActionExecutionResultTypeDef",
+        "outputVariables": Dict[str, str],
+    },
+    total=False,
+)
+
+ActionExecutionResultTypeDef = TypedDict(
+    "ActionExecutionResultTypeDef",
+    {"externalExecutionId": str, "externalExecutionSummary": str, "externalExecutionUrl": str},
+    total=False,
+)
+
+ActionExecutionTypeDef = TypedDict(
+    "ActionExecutionTypeDef",
+    {
+        "status": Literal["InProgress", "Abandoned", "Succeeded", "Failed"],
+        "summary": str,
+        "lastStatusChange": datetime,
+        "token": str,
+        "lastUpdatedBy": str,
+        "externalExecutionId": str,
+        "externalExecutionUrl": str,
+        "percentComplete": int,
+        "errorDetails": "ErrorDetailsTypeDef",
+    },
+    total=False,
 )
 
 ActionRevisionTypeDef = TypedDict(
     "ActionRevisionTypeDef", {"revisionId": str, "revisionChangeId": str, "created": datetime}
 )
 
+ActionStateTypeDef = TypedDict(
+    "ActionStateTypeDef",
+    {
+        "actionName": str,
+        "currentRevision": "ActionRevisionTypeDef",
+        "latestExecution": "ActionExecutionTypeDef",
+        "entityUrl": str,
+        "revisionUrl": str,
+    },
+    total=False,
+)
+
 ActionTypeIdTypeDef = TypedDict(
     "ActionTypeIdTypeDef",
     {
@@ -173,27 +261,19 @@ ActionTypeSettingsTypeDef = TypedDict(
     total=False,
 )
 
-ApprovalResultTypeDef = TypedDict(
-    "ApprovalResultTypeDef", {"summary": str, "status": Literal["Approved", "Rejected"]}
-)
-
-ArtifactDetailsTypeDef = TypedDict(
-    "ArtifactDetailsTypeDef", {"minimumCount": int, "maximumCount": int}
-)
-
 _RequiredActionTypeTypeDef = TypedDict(
     "_RequiredActionTypeTypeDef",
     {
-        "id": ActionTypeIdTypeDef,
-        "inputArtifactDetails": ArtifactDetailsTypeDef,
-        "outputArtifactDetails": ArtifactDetailsTypeDef,
+        "id": "ActionTypeIdTypeDef",
+        "inputArtifactDetails": "ArtifactDetailsTypeDef",
+        "outputArtifactDetails": "ArtifactDetailsTypeDef",
     },
 )
 _OptionalActionTypeTypeDef = TypedDict(
     "_OptionalActionTypeTypeDef",
     {
-        "settings": ActionTypeSettingsTypeDef,
-        "actionConfigurationProperties": List[ActionConfigurationPropertyTypeDef],
+        "settings": "ActionTypeSettingsTypeDef",
+        "actionConfigurationProperties": List["ActionConfigurationPropertyTypeDef"],
     },
     total=False,
 )
@@ -203,29 +283,38 @@ class ActionTypeTypeDef(_RequiredActionTypeTypeDef, _OptionalActionTypeTypeDef):
     pass
 
 
-TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str})
-
-_RequiredCreateCustomActionTypeOutputTypeDef = TypedDict(
-    "_RequiredCreateCustomActionTypeOutputTypeDef", {"actionType": ActionTypeTypeDef}
-)
-_OptionalCreateCustomActionTypeOutputTypeDef = TypedDict(
-    "_OptionalCreateCustomActionTypeOutputTypeDef", {"tags": List[TagTypeDef]}, total=False
+ArtifactDetailTypeDef = TypedDict(
+    "ArtifactDetailTypeDef", {"name": str, "s3location": "S3LocationTypeDef"}, total=False
 )
 
+ArtifactDetailsTypeDef = TypedDict(
+    "ArtifactDetailsTypeDef", {"minimumCount": int, "maximumCount": int}
+)
 
-class CreateCustomActionTypeOutputTypeDef(
-    _RequiredCreateCustomActionTypeOutputTypeDef, _OptionalCreateCustomActionTypeOutputTypeDef
-):
-    pass
+ArtifactLocationTypeDef = TypedDict(
+    "ArtifactLocationTypeDef",
+    {"type": Literal["S3"], "s3Location": "S3ArtifactLocationTypeDef"},
+    total=False,
+)
 
-
-EncryptionKeyTypeDef = TypedDict("EncryptionKeyTypeDef", {"id": str, "type": Literal["KMS"]})
+ArtifactRevisionTypeDef = TypedDict(
+    "ArtifactRevisionTypeDef",
+    {
+        "name": str,
+        "revisionId": str,
+        "revisionChangeIdentifier": str,
+        "revisionSummary": str,
+        "created": datetime,
+        "revisionUrl": str,
+    },
+    total=False,
+)
 
 _RequiredArtifactStoreTypeDef = TypedDict(
     "_RequiredArtifactStoreTypeDef", {"type": Literal["S3"], "location": str}
 )
 _OptionalArtifactStoreTypeDef = TypedDict(
-    "_OptionalArtifactStoreTypeDef", {"encryptionKey": EncryptionKeyTypeDef}, total=False
+    "_OptionalArtifactStoreTypeDef", {"encryptionKey": "EncryptionKeyTypeDef"}, total=False
 )
 
 
@@ -233,59 +322,104 @@ class ArtifactStoreTypeDef(_RequiredArtifactStoreTypeDef, _OptionalArtifactStore
     pass
 
 
-InputArtifactTypeDef = TypedDict("InputArtifactTypeDef", {"name": str})
-
-OutputArtifactTypeDef = TypedDict("OutputArtifactTypeDef", {"name": str})
-
-_RequiredActionDeclarationTypeDef = TypedDict(
-    "_RequiredActionDeclarationTypeDef", {"name": str, "actionTypeId": ActionTypeIdTypeDef}
-)
-_OptionalActionDeclarationTypeDef = TypedDict(
-    "_OptionalActionDeclarationTypeDef",
-    {
-        "runOrder": int,
-        "configuration": Dict[str, str],
-        "outputArtifacts": List[OutputArtifactTypeDef],
-        "inputArtifacts": List[InputArtifactTypeDef],
-        "roleArn": str,
-        "region": str,
-        "namespace": str,
-    },
+ArtifactTypeDef = TypedDict(
+    "ArtifactTypeDef",
+    {"name": str, "revision": str, "location": "ArtifactLocationTypeDef"},
     total=False,
 )
 
-
-class ActionDeclarationTypeDef(
-    _RequiredActionDeclarationTypeDef, _OptionalActionDeclarationTypeDef
-):
-    pass
-
-
 BlockerDeclarationTypeDef = TypedDict(
     "BlockerDeclarationTypeDef", {"name": str, "type": Literal["Schedule"]}
 )
 
-_RequiredStageDeclarationTypeDef = TypedDict(
-    "_RequiredStageDeclarationTypeDef", {"name": str, "actions": List[ActionDeclarationTypeDef]}
+EncryptionKeyTypeDef = TypedDict("EncryptionKeyTypeDef", {"id": str, "type": Literal["KMS"]})
+
+ErrorDetailsTypeDef = TypedDict("ErrorDetailsTypeDef", {"code": str, "message": str}, total=False)
+
+ExecutionTriggerTypeDef = TypedDict(
+    "ExecutionTriggerTypeDef",
+    {
+        "triggerType": Literal[
+            "CreatePipeline",
+            "StartPipelineExecution",
+            "PollForSourceChanges",
+            "Webhook",
+            "CloudWatchEvent",
+            "PutActionRevision",
+        ],
+        "triggerDetail": str,
+    },
+    total=False,
 )
-_OptionalStageDeclarationTypeDef = TypedDict(
-    "_OptionalStageDeclarationTypeDef", {"blockers": List[BlockerDeclarationTypeDef]}, total=False
+
+InputArtifactTypeDef = TypedDict("InputArtifactTypeDef", {"name": str})
+
+JobDataTypeDef = TypedDict(
+    "JobDataTypeDef",
+    {
+        "actionTypeId": "ActionTypeIdTypeDef",
+        "actionConfiguration": "ActionConfigurationTypeDef",
+        "pipelineContext": "PipelineContextTypeDef",
+        "inputArtifacts": List["ArtifactTypeDef"],
+        "outputArtifacts": List["ArtifactTypeDef"],
+        "artifactCredentials": "AWSSessionCredentialsTypeDef",
+        "continuationToken": str,
+        "encryptionKey": "EncryptionKeyTypeDef",
+    },
+    total=False,
+)
+
+JobDetailsTypeDef = TypedDict(
+    "JobDetailsTypeDef", {"id": str, "data": "JobDataTypeDef", "accountId": str}, total=False
+)
+
+JobTypeDef = TypedDict(
+    "JobTypeDef", {"id": str, "data": "JobDataTypeDef", "nonce": str, "accountId": str}, total=False
+)
+
+_RequiredListWebhookItemTypeDef = TypedDict(
+    "_RequiredListWebhookItemTypeDef", {"definition": "WebhookDefinitionTypeDef", "url": str}
+)
+_OptionalListWebhookItemTypeDef = TypedDict(
+    "_OptionalListWebhookItemTypeDef",
+    {
+        "errorMessage": str,
+        "errorCode": str,
+        "lastTriggered": datetime,
+        "arn": str,
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
 )
 
 
-class StageDeclarationTypeDef(_RequiredStageDeclarationTypeDef, _OptionalStageDeclarationTypeDef):
+class ListWebhookItemTypeDef(_RequiredListWebhookItemTypeDef, _OptionalListWebhookItemTypeDef):
     pass
 
 
+OutputArtifactTypeDef = TypedDict("OutputArtifactTypeDef", {"name": str})
+
+PipelineContextTypeDef = TypedDict(
+    "PipelineContextTypeDef",
+    {
+        "pipelineName": str,
+        "stage": "StageContextTypeDef",
+        "action": "ActionContextTypeDef",
+        "pipelineArn": str,
+        "pipelineExecutionId": str,
+    },
+    total=False,
+)
+
 _RequiredPipelineDeclarationTypeDef = TypedDict(
     "_RequiredPipelineDeclarationTypeDef",
-    {"name": str, "roleArn": str, "stages": List[StageDeclarationTypeDef]},
+    {"name": str, "roleArn": str, "stages": List["StageDeclarationTypeDef"]},
 )
 _OptionalPipelineDeclarationTypeDef = TypedDict(
     "_OptionalPipelineDeclarationTypeDef",
     {
-        "artifactStore": ArtifactStoreTypeDef,
-        "artifactStores": Dict[str, ArtifactStoreTypeDef],
+        "artifactStore": "ArtifactStoreTypeDef",
+        "artifactStores": Dict[str, "ArtifactStoreTypeDef"],
         "version": int,
     },
     total=False,
@@ -298,9 +432,205 @@ class PipelineDeclarationTypeDef(
     pass
 
 
+PipelineExecutionSummaryTypeDef = TypedDict(
+    "PipelineExecutionSummaryTypeDef",
+    {
+        "pipelineExecutionId": str,
+        "status": Literal["InProgress", "Stopped", "Stopping", "Succeeded", "Superseded", "Failed"],
+        "startTime": datetime,
+        "lastUpdateTime": datetime,
+        "sourceRevisions": List["SourceRevisionTypeDef"],
+        "trigger": "ExecutionTriggerTypeDef",
+        "stopTrigger": "StopExecutionTriggerTypeDef",
+    },
+    total=False,
+)
+
+PipelineExecutionTypeDef = TypedDict(
+    "PipelineExecutionTypeDef",
+    {
+        "pipelineName": str,
+        "pipelineVersion": int,
+        "pipelineExecutionId": str,
+        "status": Literal["InProgress", "Stopped", "Stopping", "Succeeded", "Superseded", "Failed"],
+        "artifactRevisions": List["ArtifactRevisionTypeDef"],
+    },
+    total=False,
+)
+
+PipelineMetadataTypeDef = TypedDict(
+    "PipelineMetadataTypeDef",
+    {"pipelineArn": str, "created": datetime, "updated": datetime},
+    total=False,
+)
+
+PipelineSummaryTypeDef = TypedDict(
+    "PipelineSummaryTypeDef",
+    {"name": str, "version": int, "created": datetime, "updated": datetime},
+    total=False,
+)
+
+S3ArtifactLocationTypeDef = TypedDict(
+    "S3ArtifactLocationTypeDef", {"bucketName": str, "objectKey": str}
+)
+
+S3LocationTypeDef = TypedDict("S3LocationTypeDef", {"bucket": str, "key": str}, total=False)
+
+_RequiredSourceRevisionTypeDef = TypedDict("_RequiredSourceRevisionTypeDef", {"actionName": str})
+_OptionalSourceRevisionTypeDef = TypedDict(
+    "_OptionalSourceRevisionTypeDef",
+    {"revisionId": str, "revisionSummary": str, "revisionUrl": str},
+    total=False,
+)
+
+
+class SourceRevisionTypeDef(_RequiredSourceRevisionTypeDef, _OptionalSourceRevisionTypeDef):
+    pass
+
+
+StageContextTypeDef = TypedDict("StageContextTypeDef", {"name": str}, total=False)
+
+_RequiredStageDeclarationTypeDef = TypedDict(
+    "_RequiredStageDeclarationTypeDef", {"name": str, "actions": List["ActionDeclarationTypeDef"]}
+)
+_OptionalStageDeclarationTypeDef = TypedDict(
+    "_OptionalStageDeclarationTypeDef", {"blockers": List["BlockerDeclarationTypeDef"]}, total=False
+)
+
+
+class StageDeclarationTypeDef(_RequiredStageDeclarationTypeDef, _OptionalStageDeclarationTypeDef):
+    pass
+
+
+StageExecutionTypeDef = TypedDict(
+    "StageExecutionTypeDef",
+    {
+        "pipelineExecutionId": str,
+        "status": Literal["InProgress", "Failed", "Stopped", "Stopping", "Succeeded"],
+    },
+)
+
+StageStateTypeDef = TypedDict(
+    "StageStateTypeDef",
+    {
+        "stageName": str,
+        "inboundTransitionState": "TransitionStateTypeDef",
+        "actionStates": List["ActionStateTypeDef"],
+        "latestExecution": "StageExecutionTypeDef",
+    },
+    total=False,
+)
+
+StopExecutionTriggerTypeDef = TypedDict("StopExecutionTriggerTypeDef", {"reason": str}, total=False)
+
+TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str})
+
+ThirdPartyJobDataTypeDef = TypedDict(
+    "ThirdPartyJobDataTypeDef",
+    {
+        "actionTypeId": "ActionTypeIdTypeDef",
+        "actionConfiguration": "ActionConfigurationTypeDef",
+        "pipelineContext": "PipelineContextTypeDef",
+        "inputArtifacts": List["ArtifactTypeDef"],
+        "outputArtifacts": List["ArtifactTypeDef"],
+        "artifactCredentials": "AWSSessionCredentialsTypeDef",
+        "continuationToken": str,
+        "encryptionKey": "EncryptionKeyTypeDef",
+    },
+    total=False,
+)
+
+ThirdPartyJobDetailsTypeDef = TypedDict(
+    "ThirdPartyJobDetailsTypeDef",
+    {"id": str, "data": "ThirdPartyJobDataTypeDef", "nonce": str},
+    total=False,
+)
+
+ThirdPartyJobTypeDef = TypedDict(
+    "ThirdPartyJobTypeDef", {"clientId": str, "jobId": str}, total=False
+)
+
+TransitionStateTypeDef = TypedDict(
+    "TransitionStateTypeDef",
+    {"enabled": bool, "lastChangedBy": str, "lastChangedAt": datetime, "disabledReason": str},
+    total=False,
+)
+
+WebhookAuthConfigurationTypeDef = TypedDict(
+    "WebhookAuthConfigurationTypeDef", {"AllowedIPRange": str, "SecretToken": str}, total=False
+)
+
+WebhookDefinitionTypeDef = TypedDict(
+    "WebhookDefinitionTypeDef",
+    {
+        "name": str,
+        "targetPipeline": str,
+        "targetAction": str,
+        "filters": List["WebhookFilterRuleTypeDef"],
+        "authentication": Literal["GITHUB_HMAC", "IP", "UNAUTHENTICATED"],
+        "authenticationConfiguration": "WebhookAuthConfigurationTypeDef",
+    },
+)
+
+_RequiredWebhookFilterRuleTypeDef = TypedDict(
+    "_RequiredWebhookFilterRuleTypeDef", {"jsonPath": str}
+)
+_OptionalWebhookFilterRuleTypeDef = TypedDict(
+    "_OptionalWebhookFilterRuleTypeDef", {"matchEquals": str}, total=False
+)
+
+
+class WebhookFilterRuleTypeDef(
+    _RequiredWebhookFilterRuleTypeDef, _OptionalWebhookFilterRuleTypeDef
+):
+    pass
+
+
+AcknowledgeJobOutputTypeDef = TypedDict(
+    "AcknowledgeJobOutputTypeDef",
+    {
+        "status": Literal[
+            "Created", "Queued", "Dispatched", "InProgress", "TimedOut", "Succeeded", "Failed"
+        ]
+    },
+    total=False,
+)
+
+AcknowledgeThirdPartyJobOutputTypeDef = TypedDict(
+    "AcknowledgeThirdPartyJobOutputTypeDef",
+    {
+        "status": Literal[
+            "Created", "Queued", "Dispatched", "InProgress", "TimedOut", "Succeeded", "Failed"
+        ]
+    },
+    total=False,
+)
+
+ActionExecutionFilterTypeDef = TypedDict(
+    "ActionExecutionFilterTypeDef", {"pipelineExecutionId": str}, total=False
+)
+
+ApprovalResultTypeDef = TypedDict(
+    "ApprovalResultTypeDef", {"summary": str, "status": Literal["Approved", "Rejected"]}
+)
+
+_RequiredCreateCustomActionTypeOutputTypeDef = TypedDict(
+    "_RequiredCreateCustomActionTypeOutputTypeDef", {"actionType": "ActionTypeTypeDef"}
+)
+_OptionalCreateCustomActionTypeOutputTypeDef = TypedDict(
+    "_OptionalCreateCustomActionTypeOutputTypeDef", {"tags": List["TagTypeDef"]}, total=False
+)
+
+
+class CreateCustomActionTypeOutputTypeDef(
+    _RequiredCreateCustomActionTypeOutputTypeDef, _OptionalCreateCustomActionTypeOutputTypeDef
+):
+    pass
+
+
 CreatePipelineOutputTypeDef = TypedDict(
     "CreatePipelineOutputTypeDef",
-    {"pipeline": PipelineDeclarationTypeDef, "tags": List[TagTypeDef]},
+    {"pipeline": "PipelineDeclarationTypeDef", "tags": List["TagTypeDef"]},
     total=False,
 )
 
@@ -345,167 +675,19 @@ class FailureDetailsTypeDef(_RequiredFailureDetailsTypeDef, _OptionalFailureDeta
     pass
 
 
-AWSSessionCredentialsTypeDef = TypedDict(
-    "AWSSessionCredentialsTypeDef",
-    {"accessKeyId": str, "secretAccessKey": str, "sessionToken": str},
-)
-
-ActionConfigurationTypeDef = TypedDict(
-    "ActionConfigurationTypeDef", {"configuration": Dict[str, str]}, total=False
-)
-
-S3ArtifactLocationTypeDef = TypedDict(
-    "S3ArtifactLocationTypeDef", {"bucketName": str, "objectKey": str}
-)
-
-ArtifactLocationTypeDef = TypedDict(
-    "ArtifactLocationTypeDef",
-    {"type": Literal["S3"], "s3Location": S3ArtifactLocationTypeDef},
-    total=False,
-)
-
-ArtifactTypeDef = TypedDict(
-    "ArtifactTypeDef",
-    {"name": str, "revision": str, "location": ArtifactLocationTypeDef},
-    total=False,
-)
-
-ActionContextTypeDef = TypedDict(
-    "ActionContextTypeDef", {"name": str, "actionExecutionId": str}, total=False
-)
-
-StageContextTypeDef = TypedDict("StageContextTypeDef", {"name": str}, total=False)
-
-PipelineContextTypeDef = TypedDict(
-    "PipelineContextTypeDef",
-    {
-        "pipelineName": str,
-        "stage": StageContextTypeDef,
-        "action": ActionContextTypeDef,
-        "pipelineArn": str,
-        "pipelineExecutionId": str,
-    },
-    total=False,
-)
-
-JobDataTypeDef = TypedDict(
-    "JobDataTypeDef",
-    {
-        "actionTypeId": ActionTypeIdTypeDef,
-        "actionConfiguration": ActionConfigurationTypeDef,
-        "pipelineContext": PipelineContextTypeDef,
-        "inputArtifacts": List[ArtifactTypeDef],
-        "outputArtifacts": List[ArtifactTypeDef],
-        "artifactCredentials": AWSSessionCredentialsTypeDef,
-        "continuationToken": str,
-        "encryptionKey": EncryptionKeyTypeDef,
-    },
-    total=False,
-)
-
-JobDetailsTypeDef = TypedDict(
-    "JobDetailsTypeDef", {"id": str, "data": JobDataTypeDef, "accountId": str}, total=False
-)
-
 GetJobDetailsOutputTypeDef = TypedDict(
-    "GetJobDetailsOutputTypeDef", {"jobDetails": JobDetailsTypeDef}, total=False
-)
-
-ArtifactRevisionTypeDef = TypedDict(
-    "ArtifactRevisionTypeDef",
-    {
-        "name": str,
-        "revisionId": str,
-        "revisionChangeIdentifier": str,
-        "revisionSummary": str,
-        "created": datetime,
-        "revisionUrl": str,
-    },
-    total=False,
-)
-
-PipelineExecutionTypeDef = TypedDict(
-    "PipelineExecutionTypeDef",
-    {
-        "pipelineName": str,
-        "pipelineVersion": int,
-        "pipelineExecutionId": str,
-        "status": Literal["InProgress", "Stopped", "Stopping", "Succeeded", "Superseded", "Failed"],
-        "artifactRevisions": List[ArtifactRevisionTypeDef],
-    },
-    total=False,
+    "GetJobDetailsOutputTypeDef", {"jobDetails": "JobDetailsTypeDef"}, total=False
 )
 
 GetPipelineExecutionOutputTypeDef = TypedDict(
     "GetPipelineExecutionOutputTypeDef",
-    {"pipelineExecution": PipelineExecutionTypeDef},
-    total=False,
-)
-
-PipelineMetadataTypeDef = TypedDict(
-    "PipelineMetadataTypeDef",
-    {"pipelineArn": str, "created": datetime, "updated": datetime},
+    {"pipelineExecution": "PipelineExecutionTypeDef"},
     total=False,
 )
 
 GetPipelineOutputTypeDef = TypedDict(
     "GetPipelineOutputTypeDef",
-    {"pipeline": PipelineDeclarationTypeDef, "metadata": PipelineMetadataTypeDef},
-    total=False,
-)
-
-ErrorDetailsTypeDef = TypedDict("ErrorDetailsTypeDef", {"code": str, "message": str}, total=False)
-
-ActionExecutionTypeDef = TypedDict(
-    "ActionExecutionTypeDef",
-    {
-        "status": Literal["InProgress", "Abandoned", "Succeeded", "Failed"],
-        "summary": str,
-        "lastStatusChange": datetime,
-        "token": str,
-        "lastUpdatedBy": str,
-        "externalExecutionId": str,
-        "externalExecutionUrl": str,
-        "percentComplete": int,
-        "errorDetails": ErrorDetailsTypeDef,
-    },
-    total=False,
-)
-
-ActionStateTypeDef = TypedDict(
-    "ActionStateTypeDef",
-    {
-        "actionName": str,
-        "currentRevision": ActionRevisionTypeDef,
-        "latestExecution": ActionExecutionTypeDef,
-        "entityUrl": str,
-        "revisionUrl": str,
-    },
-    total=False,
-)
-
-StageExecutionTypeDef = TypedDict(
-    "StageExecutionTypeDef",
-    {
-        "pipelineExecutionId": str,
-        "status": Literal["InProgress", "Failed", "Stopped", "Stopping", "Succeeded"],
-    },
-)
-
-TransitionStateTypeDef = TypedDict(
-    "TransitionStateTypeDef",
-    {"enabled": bool, "lastChangedBy": str, "lastChangedAt": datetime, "disabledReason": str},
-    total=False,
-)
-
-StageStateTypeDef = TypedDict(
-    "StageStateTypeDef",
-    {
-        "stageName": str,
-        "inboundTransitionState": TransitionStateTypeDef,
-        "actionStates": List[ActionStateTypeDef],
-        "latestExecution": StageExecutionTypeDef,
-    },
+    {"pipeline": "PipelineDeclarationTypeDef", "metadata": "PipelineMetadataTypeDef"},
     total=False,
 )
 
@@ -514,99 +696,27 @@ GetPipelineStateOutputTypeDef = TypedDict(
     {
         "pipelineName": str,
         "pipelineVersion": int,
-        "stageStates": List[StageStateTypeDef],
+        "stageStates": List["StageStateTypeDef"],
         "created": datetime,
         "updated": datetime,
     },
     total=False,
 )
 
-ThirdPartyJobDataTypeDef = TypedDict(
-    "ThirdPartyJobDataTypeDef",
-    {
-        "actionTypeId": ActionTypeIdTypeDef,
-        "actionConfiguration": ActionConfigurationTypeDef,
-        "pipelineContext": PipelineContextTypeDef,
-        "inputArtifacts": List[ArtifactTypeDef],
-        "outputArtifacts": List[ArtifactTypeDef],
-        "artifactCredentials": AWSSessionCredentialsTypeDef,
-        "continuationToken": str,
-        "encryptionKey": EncryptionKeyTypeDef,
-    },
-    total=False,
-)
-
-ThirdPartyJobDetailsTypeDef = TypedDict(
-    "ThirdPartyJobDetailsTypeDef",
-    {"id": str, "data": ThirdPartyJobDataTypeDef, "nonce": str},
-    total=False,
-)
-
 GetThirdPartyJobDetailsOutputTypeDef = TypedDict(
-    "GetThirdPartyJobDetailsOutputTypeDef", {"jobDetails": ThirdPartyJobDetailsTypeDef}, total=False
-)
-
-S3LocationTypeDef = TypedDict("S3LocationTypeDef", {"bucket": str, "key": str}, total=False)
-
-ArtifactDetailTypeDef = TypedDict(
-    "ArtifactDetailTypeDef", {"name": str, "s3location": S3LocationTypeDef}, total=False
-)
-
-ActionExecutionInputTypeDef = TypedDict(
-    "ActionExecutionInputTypeDef",
-    {
-        "actionTypeId": ActionTypeIdTypeDef,
-        "configuration": Dict[str, str],
-        "resolvedConfiguration": Dict[str, str],
-        "roleArn": str,
-        "region": str,
-        "inputArtifacts": List[ArtifactDetailTypeDef],
-        "namespace": str,
-    },
-    total=False,
-)
-
-ActionExecutionResultTypeDef = TypedDict(
-    "ActionExecutionResultTypeDef",
-    {"externalExecutionId": str, "externalExecutionSummary": str, "externalExecutionUrl": str},
-    total=False,
-)
-
-ActionExecutionOutputTypeDef = TypedDict(
-    "ActionExecutionOutputTypeDef",
-    {
-        "outputArtifacts": List[ArtifactDetailTypeDef],
-        "executionResult": ActionExecutionResultTypeDef,
-        "outputVariables": Dict[str, str],
-    },
-    total=False,
-)
-
-ActionExecutionDetailTypeDef = TypedDict(
-    "ActionExecutionDetailTypeDef",
-    {
-        "pipelineExecutionId": str,
-        "actionExecutionId": str,
-        "pipelineVersion": int,
-        "stageName": str,
-        "actionName": str,
-        "startTime": datetime,
-        "lastUpdateTime": datetime,
-        "status": Literal["InProgress", "Abandoned", "Succeeded", "Failed"],
-        "input": ActionExecutionInputTypeDef,
-        "output": ActionExecutionOutputTypeDef,
-    },
+    "GetThirdPartyJobDetailsOutputTypeDef",
+    {"jobDetails": "ThirdPartyJobDetailsTypeDef"},
     total=False,
 )
 
 ListActionExecutionsOutputTypeDef = TypedDict(
     "ListActionExecutionsOutputTypeDef",
-    {"actionExecutionDetails": List[ActionExecutionDetailTypeDef], "nextToken": str},
+    {"actionExecutionDetails": List["ActionExecutionDetailTypeDef"], "nextToken": str},
     total=False,
 )
 
 _RequiredListActionTypesOutputTypeDef = TypedDict(
-    "_RequiredListActionTypesOutputTypeDef", {"actionTypes": List[ActionTypeTypeDef]}
+    "_RequiredListActionTypesOutputTypeDef", {"actionTypes": List["ActionTypeTypeDef"]}
 )
 _OptionalListActionTypesOutputTypeDef = TypedDict(
     "_OptionalListActionTypesOutputTypeDef", {"nextToken": str}, total=False
@@ -619,125 +729,25 @@ class ListActionTypesOutputTypeDef(
     pass
 
 
-ExecutionTriggerTypeDef = TypedDict(
-    "ExecutionTriggerTypeDef",
-    {
-        "triggerType": Literal[
-            "CreatePipeline",
-            "StartPipelineExecution",
-            "PollForSourceChanges",
-            "Webhook",
-            "CloudWatchEvent",
-            "PutActionRevision",
-        ],
-        "triggerDetail": str,
-    },
-    total=False,
-)
-
-_RequiredSourceRevisionTypeDef = TypedDict("_RequiredSourceRevisionTypeDef", {"actionName": str})
-_OptionalSourceRevisionTypeDef = TypedDict(
-    "_OptionalSourceRevisionTypeDef",
-    {"revisionId": str, "revisionSummary": str, "revisionUrl": str},
-    total=False,
-)
-
-
-class SourceRevisionTypeDef(_RequiredSourceRevisionTypeDef, _OptionalSourceRevisionTypeDef):
-    pass
-
-
-StopExecutionTriggerTypeDef = TypedDict("StopExecutionTriggerTypeDef", {"reason": str}, total=False)
-
-PipelineExecutionSummaryTypeDef = TypedDict(
-    "PipelineExecutionSummaryTypeDef",
-    {
-        "pipelineExecutionId": str,
-        "status": Literal["InProgress", "Stopped", "Stopping", "Succeeded", "Superseded", "Failed"],
-        "startTime": datetime,
-        "lastUpdateTime": datetime,
-        "sourceRevisions": List[SourceRevisionTypeDef],
-        "trigger": ExecutionTriggerTypeDef,
-        "stopTrigger": StopExecutionTriggerTypeDef,
-    },
-    total=False,
-)
-
 ListPipelineExecutionsOutputTypeDef = TypedDict(
     "ListPipelineExecutionsOutputTypeDef",
-    {"pipelineExecutionSummaries": List[PipelineExecutionSummaryTypeDef], "nextToken": str},
-    total=False,
-)
-
-PipelineSummaryTypeDef = TypedDict(
-    "PipelineSummaryTypeDef",
-    {"name": str, "version": int, "created": datetime, "updated": datetime},
+    {"pipelineExecutionSummaries": List["PipelineExecutionSummaryTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListPipelinesOutputTypeDef = TypedDict(
     "ListPipelinesOutputTypeDef",
-    {"pipelines": List[PipelineSummaryTypeDef], "nextToken": str},
+    {"pipelines": List["PipelineSummaryTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListTagsForResourceOutputTypeDef = TypedDict(
-    "ListTagsForResourceOutputTypeDef", {"tags": List[TagTypeDef], "nextToken": str}, total=False
+    "ListTagsForResourceOutputTypeDef", {"tags": List["TagTypeDef"], "nextToken": str}, total=False
 )
 
-WebhookAuthConfigurationTypeDef = TypedDict(
-    "WebhookAuthConfigurationTypeDef", {"AllowedIPRange": str, "SecretToken": str}, total=False
-)
-
-_RequiredWebhookFilterRuleTypeDef = TypedDict(
-    "_RequiredWebhookFilterRuleTypeDef", {"jsonPath": str}
-)
-_OptionalWebhookFilterRuleTypeDef = TypedDict(
-    "_OptionalWebhookFilterRuleTypeDef", {"matchEquals": str}, total=False
-)
-
-
-class WebhookFilterRuleTypeDef(
-    _RequiredWebhookFilterRuleTypeDef, _OptionalWebhookFilterRuleTypeDef
-):
-    pass
-
-
-WebhookDefinitionTypeDef = TypedDict(
-    "WebhookDefinitionTypeDef",
-    {
-        "name": str,
-        "targetPipeline": str,
-        "targetAction": str,
-        "filters": List[WebhookFilterRuleTypeDef],
-        "authentication": Literal["GITHUB_HMAC", "IP", "UNAUTHENTICATED"],
-        "authenticationConfiguration": WebhookAuthConfigurationTypeDef,
-    },
-)
-
-_RequiredListWebhookItemTypeDef = TypedDict(
-    "_RequiredListWebhookItemTypeDef", {"definition": WebhookDefinitionTypeDef, "url": str}
-)
-_OptionalListWebhookItemTypeDef = TypedDict(
-    "_OptionalListWebhookItemTypeDef",
-    {
-        "errorMessage": str,
-        "errorCode": str,
-        "lastTriggered": datetime,
-        "arn": str,
-        "tags": List[TagTypeDef],
-    },
-    total=False,
-)
-
-
-class ListWebhookItemTypeDef(_RequiredListWebhookItemTypeDef, _OptionalListWebhookItemTypeDef):
-    pass
-
-
 ListWebhooksOutputTypeDef = TypedDict(
     "ListWebhooksOutputTypeDef",
-    {"webhooks": List[ListWebhookItemTypeDef], "NextToken": str},
+    {"webhooks": List["ListWebhookItemTypeDef"], "NextToken": str},
     total=False,
 )
 
@@ -745,20 +755,12 @@ PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
 
-JobTypeDef = TypedDict(
-    "JobTypeDef", {"id": str, "data": JobDataTypeDef, "nonce": str, "accountId": str}, total=False
-)
-
 PollForJobsOutputTypeDef = TypedDict(
-    "PollForJobsOutputTypeDef", {"jobs": List[JobTypeDef]}, total=False
-)
-
-ThirdPartyJobTypeDef = TypedDict(
-    "ThirdPartyJobTypeDef", {"clientId": str, "jobId": str}, total=False
+    "PollForJobsOutputTypeDef", {"jobs": List["JobTypeDef"]}, total=False
 )
 
 PollForThirdPartyJobsOutputTypeDef = TypedDict(
-    "PollForThirdPartyJobsOutputTypeDef", {"jobs": List[ThirdPartyJobTypeDef]}, total=False
+    "PollForThirdPartyJobsOutputTypeDef", {"jobs": List["ThirdPartyJobTypeDef"]}, total=False
 )
 
 PutActionRevisionOutputTypeDef = TypedDict(
@@ -770,7 +772,7 @@ PutApprovalResultOutputTypeDef = TypedDict(
 )
 
 PutWebhookOutputTypeDef = TypedDict(
-    "PutWebhookOutputTypeDef", {"webhook": ListWebhookItemTypeDef}, total=False
+    "PutWebhookOutputTypeDef", {"webhook": "ListWebhookItemTypeDef"}, total=False
 )
 
 RetryStageExecutionOutputTypeDef = TypedDict(
@@ -786,5 +788,5 @@ StopPipelineExecutionOutputTypeDef = TypedDict(
 )
 
 UpdatePipelineOutputTypeDef = TypedDict(
-    "UpdatePipelineOutputTypeDef", {"pipeline": PipelineDeclarationTypeDef}, total=False
+    "UpdatePipelineOutputTypeDef", {"pipeline": "PipelineDeclarationTypeDef"}, total=False
 )
